%monetize.m 
%Computes and plots  the equilibrium  dynamics under a monetary policy that keeps the real value of total government liabilities constant over time, w_t=w0,   in the model developed in ``Is the Monetarist Arithmetic Unpleasant?,''    by Martn Uribe. 
% Martn Uribe, November 2016. 
function monetize(HLD,tau0,T);

if nargin<3
T = 15; %time horizon of simulation, t=0:T
end

if nargin<2|isempty(tau0)
tau0 = 0.05; %initial primary fiscal deficit of 3 percent of GDP
end

if nargin<1|isempty(HLD)
HLD =   -log(0.5)/0.3; %half life of primary deficit in years
end
%get parameter values
[bs,is,pis,ms,tau0,rho,delta,w0,alfa,A,HLD,g] = qf(HLD,tau0,T);

trho = rho+alfa*g;

for j=1:T+1
t(j,1) = j-1;
tau(j,1) = tau0*exp(-delta*t(j));

i(j,1) = (((trho-g)*w0+tau(j))/A)^(1/(1-alfa));
m(j,1) = A*i(j)^(-alfa);
b(j,1) = w0-m(j);
pi(j,1) = i(j)-trho;
end
clf
subplot(2,2,1)
plot(t,tau*100,'w-','linewidth',4)
title('(a) Primary Fiscal Deficit, \tau_t')
xlabel('time in years')
ylabel('percent of GDP')

subplot(2,2,2)
plot(t,b*100,'w-',t,bs*100,'w--','linewidth',4)
title('(b) Debt, b_t')
xlabel('time in years')
ylabel('percent of GDP')

subplot(2,2,3)
plot(t,pi*100,'w-',t,t*0+pis*100,'w--','linewidth',4)
title('(c) Inflation, \pi_t')
xlabel('time in years')
ylabel('percent per year')

subplot(2,2,4)
plot(t,m*100,'w-',t,t*0+ms*100,'w--','linewidth',4)
title('(d) Monetary Base, m_t')
xlabel('time in years')
ylabel('percent of GDP')
legend('Full monetization', 'Optimal Policy','location','SouthOutside')

shg
