%[b,is,pis,ms,tau0,trho,delta,w0,alfa,A,HLD,g,tau] = qf(HLD,tau0,T);
%Compute the Ramsey optimal dynamics of public debt in the model developed in ``Is the Monetarist Arithmetic Unpleasant?''  by Martn Uribe. 
% Martn Uribe, November 2020. 
function [b,is,pis,ms,tau0,trho,delta,w0,alfa,A,HLD,g,tau] = qf(HLD,tau0,T);


if nargin<3
T=8; %time horizon of simulation, t=0:T
end

if nargin<2|isempty(tau0)
tau0 = 0.05; %initial primary fiscal deficit of 3 percent of GDP
end

if nargin<1|isempty(HLD)
HLD =   -log(0.5)/0.3; %half life of primary deficit in years, or tau_t = tau_0 exp(-0.3t).
end

g = log(1+0.02); %growth rate
trho = log(1+ 0.04); %subjective discount factor
delta = -log(1/2)/HLD; %decay rate of primary fiscal deficits
w0 = 0.389; %initial real liabilities = 10% of GDP
%Demand for Money
%Functional form 
%L(i,y) = A*y*i^(-alfa)
%Calibration of alfa:
%Kiguel and Neumeyer (1995) estimate the equation ln(m) = a0-a1 i and obtain an average value of a1 of
a1=mean([0.024 0.034 0.049 0.056 0.046  0.031 0.047]);
%The opportunity cost in K&N (1995) is measured in percent per month (so must scale by 100/12). Also, to transfrom a1, which is an interest-rate semielasicity into an elasticity, one must multiply by i. I use i=0.38 (the Lebac rate at the beginning of 2016): 
x = 0.38;
alfa  = a1*100/12*x;
%Calibration of A: In Argentina at the beginning of 2016, the monetary base was about 10% of GDP and the interest rate was 38%, so 0.10=A 0.38^(-alfa), or
A = 0.1*0.38^(alfa);

pdv_tau = tau0/(trho-g+delta); %present discounted value of primary deficits
ims = (w0+pdv_tau)*(trho-g); %i*L(i,y) in the Ramsey equilibrium

%Seignorage i*m/y = A i^(1-alfa) so the Ramsey optimal interest rate must solve
is = (ims/A)^(1/(1-alfa));
pis = is-trho; %optimal inflation rate
ms = A*is^(-alfa); %optimalreal money holdings as fraction of GDP

%Compute the optimal path of dect
for j=1:T+1
t(j,1) = j-1;
b(j,1) = (pis+g)*ms/(trho-g) - tau0/(delta+trho-g) * exp(-delta*t(j));
tau(j,1) = tau0*exp(-delta*t(j));
end
