%sensitivity.m
%returns  a 2x2 plot displaying the behavior of debt accumulation and inflation as functions of the half life of the primary fiscal deficit (top row) and the initial fiscal deficit as a function of GDP (bottom row) in the Ramsey equilibrium of the model developed in  ``Is the Monetarist Arithmetic Unpleasant?'' by Martn Uribe. 
% Martn Uribe, November 2016. 
clear all
clf

 tau0 =0.05;%initial primary fiscal deficit as fraction of output
T = 8; %length of simulation in years
hld = -log(0.5)/0.3;

%Sensitivity with respect to the half life of the  primary fiscal deficit
i = 0;
for vhld=0:0.01:30
i = i+1;
[b,is,pis,ms] = qf(vhld,tau0,T);
z_hld(i,1) = b(end)-b(1);
pis_hld(i,1) = pis;
hld_hld(i,1) = vhld;
end

subplot(2,2,1)
plot(hld_hld,z_hld*100,'linewidth',4)
xlabel('half life of deficit')
ylabel('b_8-b_0')
title('Accumulated Debt in Year 8')

subplot(2,2,2)
plot(hld_hld,pis_hld*100,'linewidth',4)
xlabel('half life of deficit')
ylabel('\pi^*')
title('Inflation Rate')
%Sensitivity with respect to the initial primary fiscal deficit

i = 0;
for vtau0=eps:0.001:0.1
i = i+1;
[b,is,pis,ms] = qf(hld,vtau0,T);
z_tau0(i,1) = b(end)-b(1);
pis_tau0(i,1) = pis;
tau0_tau0(i,1) = vtau0*100;
end

subplot(2,2,3)
plot(tau0_tau0,z_tau0*100,'linewidth',4)
xlabel('initial fiscal deficit, $\tau_0$','interpreter','latex')
ylabel('b_8-b_0')
title('Accumulated Debt in Year 8')

subplot(2,2,4)
plot(tau0_tau0,pis_tau0*100,'linewidth',4)
xlabel('initial fiscal deficit, $\tau_0$','interpreter','latex')
ylabel('\pi^*')
title('Inflation Rate')